library(tidyverse)
library(ggplot2)
require(sf)

####################################################################
########  fitting model for high and low hydrodynamic area  ########  
####################################################################

load("./output/data/data_join.Rdata")

ecotope<-st_read("./ecotopenkaart/ecotopenkaart_westerschelde_2011/ecotopenkaart_westerschelde_2011Polygon.shp")
zone_tran <- st_transform(ecotope, crs=st_crs(28992))
data_spa<-st_as_sf(x=data_join,coords=c("x.x","y.x"),crs=st_crs(28992))


intersect<-st_intersection(zone_tran,data_spa)
data_high <- intersect %>% 
  st_drop_geometry() %>% 
  select(d50,verkort,em) %>% 
  filter(grepl("Hoogdynamisch",verkort))

data_low <- intersect %>% 
  st_drop_geometry() %>% 
  select(d50,verkort,em,vel) %>% 
  filter(grepl("Laagdynamisch",verkort))

modlm_d50_high=lm(d50~em,data=data_high)
modlm_d50_low=lm(d50~em,data=data_low)
summary(modlm_d50_high)
summary(modlm_d50_low)
#save(modlm_d50_high, file="./output/predict_grainsize/modlm_d50_high.Rdata")
#save(modlm_d50_low, file="./output/predict_grainsize/modlm_d50_low.Rdata")

########################
########  plot  ########  
########################

p_high <- ggplot(data = data_high, aes(em,d50)) + 
  geom_point(fill="black",colour="black",size=8,shape=21) +
  geom_smooth(method = 'lm',span=0.4,se=TRUE,colour="#00A5FF",fill="#00A5FF",alpha=0.2,size=3)+
  scale_y_continuous(
    limits = c(0, 300),
    name = "Grain size(μm) ",
  )+
  scale_x_continuous(
    name = "Inundation ratio" ,
  )+
  theme_classic()+
  theme(
    axis.text = element_text(size = 70),
    axis.title.y = element_text( size=70,margin = margin(t = 0, r = 5, b = 0, l = 0)),
    axis.title.x = element_text(size=70,margin = margin(t = 5, r = 0, b = 0, l = 0)),
    legend.text = element_text(size = 28)
  )
ggsave(p_high, file=paste0("./output/figure/grainsize/high.png"), width = 45, height = 30, units = "cm")

p_low <-ggplot(data = data_low, aes(em,d50)) + 
  geom_point(fill="black",colour="black",size=8,shape=21) +
  geom_smooth(method = 'lm',span=0.4,se=TRUE,colour="#00A5FF",fill="#00A5FF",alpha=0.2,size=3)+
  scale_y_continuous(
    limits = c(0, 300),
    name = "Grain size(μm) ",
  )+
  scale_x_continuous(
    name = "Inundation ratio" ,
  )+
  theme_classic()+
  theme(
    axis.text = element_text(size = 70),
    axis.title.y = element_text( size=70,margin = margin(t = 0, r = 5, b = 0, l = 0)),
    axis.title.x = element_text(size=70,margin = margin(t = 5, r = 0, b = 0, l = 0)),
    legend.text = element_text(size = 28)
  )
ggsave(p_low, file=paste0("./output/figure/grainsize/low.png"), width = 45, height = 30, units = "cm")#
