library(brms)
library(tidyverse)

dataset <- read.csv("./data/VEGETATION_fig4_0.csv",stringsAsFactors = F)
ss <- rev(sort(apply(dataset[,6:22],2,sum,na.rm=T)))
specnames <- names(ss[ss>0])
#saveRDS(specnames, file=paste0("./output/data/specnames_plant.rds"))

################################
### model fitting
################################

options(mc.cores = 4,
        brms.backend = "cmdstanr")

# Set some global Stan options
CHAINS <- 4
ITER <- 4000
WARMUP <- 2000
BAYES_SEED <- 1234

dataset_fit<- select(dataset,ELEVATION,salzone)

for(i in 1:length(specnames)){
  y <- dataset[,specnames[i]]
  dataset_fit$spe <- y
  
  #fitting model
  brm_formula <- bf(spe ~ s(ELEVATION,bs="bs") + (ELEVATION|salzone), hu ~ s(ELEVATION,bs="bs") + (ELEVATION|salzone))
  
  model_hurdle_fit <- brm(
    formula = brm_formula,
    data = dataset_fit,
    family = hurdle_gamma(link = "log", link_shape = "log", link_hu = "logit"),
    chains = CHAINS, iter = ITER, warmup = WARMUP, seed = BAYES_SEED,
    init = 0,
    core=4,
    control = list(adapt_delta = 0.999,max_treedepth = 10),
    silent = 2
  )
  
  save(model_hurdle_fit, file=paste0("./output/model/model_bs_plant/ele/model_hurdle_plant_bs_",i,".Rdata"))
}





