library(tidyverse)
library(nls2)

dataset <- read.csv("data/VEGETATION_fig4_0.csv",stringsAsFactors = F)

Fre_to_time1 <- function(Fre){
  m=701
  H=2.21
  Ta=2.25
  ele <- (log((m/Fre)-1)/5.648)+H
  inun_time <- 1-(acos((0-ele)/Ta)/pi)
  return(inun_time)
}
Fre_to_time2 <- function(Fre){
  m=703
  H=2.38
  Ta=2.5
  ele <- (log((m/Fre)-1)/5.648)+H
  inun_time <- 1-(acos((0-ele)/Ta)/pi)
  return(inun_time)
}
Fre_to_time3 <- function(Fre){
  m=705
  H=2.65
  Ta=2.75
  ele <- (log((m/Fre)-1)/5.648)+H
  inun_time <- 1-(acos((0-ele)/Ta)/pi)
  return(inun_time)
}

#Salinity zone1
data1 <-dataset %>%  
  filter(salzone=="Sterk polyhalien",ELEVATION<=687.5)
data1$inun_time <- sapply(data1$ELEVATION,Fre_to_time1)
data1$inun_time[is.nan(data1$inun_time)]<-0

data_fit1 <- data.frame(Biomass=data1$SUM*0.01,inun=data1$inun_time)
f_veg_inun <- Biomass ~ b*(inun^2)+c

model_veg_inun1 <- nls(f_veg_inun,
                       data = data_fit1,
                       start = list(b=0,c=0))
summary(model_veg_inun1)

par(mar = c(4.5, 4.5, 4.5, 4.5))
plot(data_fit1$Biomass ~ data_fit1$inun, xlab="Inundation ratio", ylab="Coverage",cex.lab=2, cex.axis=2)
lines(fitted(model_veg_inun1) ~ data_fit1$inun, col = "red",lwd = 1.5)


#Salinity zone2
data2 <-dataset %>%  
  filter(salzone=="Zwak polyhalien",ELEVATION<=687.5)
data2$inun_time <- sapply(data2$ELEVATION,Fre_to_time2)
data2$inun_time[is.nan(data2$inun_time)]<-0

data_fit2 <- data.frame(Biomass=data2$SUM*0.01,inun=data2$inun_time)
f_veg_inun2 <- Biomass ~ b*(inun^2)+0.6

model_veg_inun2 <- nls(f_veg_inun2,
                       data = data_fit2,
                       start = list(b=0))
summary(model_veg_inun2)


par(mar = c(4.5, 4.5, 4.5, 4.5))
plot(data_fit2$Biomass ~ data_fit2$inun, xlab="Inundation ratio", ylab="Coverage",cex.lab=2, cex.axis=2)
lines(fitted(model_veg_inun2) ~ data_fit2$inun, col = "red",lwd = 1.5)

#Salinity zone3
data3 <-dataset %>%  
  filter(salzone=="Mesohalien",ELEVATION<=687.5)
data3$inun_time <- sapply(data3$ELEVATION,Fre_to_time3)
data3$inun_time[is.nan(data3$inun_time)]<-0

data_fit3 <- data.frame(Biomass=data3$SUM*0.01,inun=data3$inun_time)
data_fit3 <- data_fit3[order(data_fit3$inun),]

model_veg_inun3 <- nls(f_veg_inun,
                       data = data_fit3, 
                       start = list(b=0,c=0))
summary(model_veg_inun3)

par(mar = c(4.5, 4.5, 4.5, 4.5))
plot(data_fit3$Biomass ~ data_fit3$inun, xlab="Inundation ratio", ylab="Coverage",cex.lab=2, cex.axis=2)
lines(fitted(model_veg_inun3) ~ data_fit3$inun, col = "red",lwd = 1.5)
