
# README

This repository contains the data and scripts used to produce the results presented in the manuscript: Effect of Upscaling Nature-Based Coastal Protection on Estuarine Biodiversity Using Foreshores and Transitional Polders. The files are organized into three main sections: Data, Model, and Prediction & Visualization.


##Data part

ABIO.csv - Environmental data corresponding to benthos observations, including water depth (bat) and inundation ratio (em).

BIOM.csv - Benthos biomass data (mg AFDW m-2).

Measured_d50_revised - Grain size data corresponding to benthos observations (µm).

VEGETATION - Plant coverage data and corresponding environmental variables, including salinity and inundation frequency (ELEVATION).

gebiedsindeling_omes_april2016.zip - Salinity zone map, downloaded from https://www.omes-monitoring.be/en/monitoring

ecotopenkaart_westerschelde_2011 - Ecotope maps, obtained from Rijkswaterstaat.



##Model part

Model_benthos.R – Bayesian hierarchical model fitting for each benthic species using benthos data.

Model_plant.R – Bayesian hierarchical model fitting for each plant species using plant data.

Parameter_veg.R – Assumes plant biomass follows a parabolic relationship with inundation time, with parameters estimated from plant data.

GrainSize_Pre.R – Classifies the study area into high- and low-dynamic zones based on the Ecotope maps, then fits a linear relationship between inundation time and grain size (see Figure S2).

Niche_color.R – Ranks species based on their predicted optimal ecological niche and assigns colors accordingly (Figure S3).

Niche_plot.R – Plots species niche distributions and species proportions along gradients of elevation and grain size (Figure 4).



##Prediction part

Predict_benthos - Uses the environmental prediction of the biomorphodynamic model to further predict the biomass and occurrence probability of benthos

Predict_plant - Uses the environmental prediction of the biomorphodynamic model to further predict the biomass and occurrence probability of plant

Logistic_benthos - Fits the results from the statistical model to a logistic model and produce biomass results over time


##Visualization

Bio_profile_plot - Use the data predicted by the scripts(Predict_benthos, Predict_plant) to plot the distribution of diversity along the profile (Figure 5 e,f,g,h).

Bio_time_plot - Calculate biodiversity index over time and plot them to compare SFP and LTP(Figure 6)

Prop_plot - Plot the proportion of plants and benthos changing over time(Figure S10).

Ele_inun_plot - Plot the elevation and inundation changing over time (Figure 5 a,b,c,d).



